@@ -255,7 +255,7 @@ def fpnd(
     assert device == "cuda" or device == "cpu", "Invalid device type"
 
     if dataset_name == "jetnet":
-        JetNet.fpnd_norm(jets)
+        JetNet.fpnd_norm(jets, inplace=True)
         # TODO other datasets
 
     # ParticleNet module and the real mu's and sigma's are cached in memory after the first load
@@ -273,7 +273,7 @@ def fpnd(
     sigma1 = _eval_module.fpnd_dict[dataset_name][num_particles][jet_type]["sigma"]
 
     # run inference and store activations
-    jets_loaded = DataLoader(jets[:, :, : _eval_module.fpnd_dict["NUM_SAMPLES"]], batch_size)
+    jets_loaded = DataLoader(jets[: _eval_module.fpnd_dict["NUM_SAMPLES"]], batch_size)
 
     logging.info(f"Calculating ParticleNet activations with batch size: {batch_size}")
     activations = []
